@@ -235,11 +235,14 @@ class Stream(object):
         self.writeSByte(num)
         self.seek(current)
 
-    def writeHalf(self, num):
+    def writeHalf(self, num, little=True):
         if self.half is None:
             self.half = num
         else:
-            self.writeByte((num << 4) | self.half)
+            if little:
+                self.writeByte((num << 4) | self.half)
+            else:
+                self.writeByte((self.half << 4) | num)
             self.half = None
 
     def writeString(self, str):
@@ -515,15 +518,22 @@ def wordwrap(text, glyphs, width, codefunc=None, default=6, linebreak="|", secti
     return linebreak.join(lines)
 
 
-def centerLines(text, glyphs, width, default=6, linebreak="|", centercode="<<"):
+def centerLines(text, glyphs, width, codefunc=None, default=6, linebreak="|", centercode="<<"):
     lines = text.split(linebreak)
     for i in range(len(lines)):
         if not lines[i].startswith(centercode):
             continue
         lines[i] = lines[i][len(centercode):]
         length = 0
-        for c in lines[i]:
-            length += glyphs[c].length if c in glyphs else default
+        j = 0
+        while j < len(lines[i]):
+            if codefunc is not None:
+                skip = codefunc(lines[i], j)
+                if skip > 0:
+                    j += skip
+                    continue
+            length += glyphs[lines[i][j]].length if lines[i][j] in glyphs else default
+            j += 1
         spacelen = glyphs[" "].length
         spacing = int(((width - length) / 2) / spacelen)
         lines[i] = (" " * spacing) + lines[i]
